**********************
Backend library
**********************

Numerical backend library containing a concrete low-level problem formulation coupled to a solver that is either included as fully self-contained C code, linked in with a dependency on the C++ CasADi runtime library and chosen solver plugin such as IPOPT, or linked in as third-party dependencies such as OSQP or GRAMPC.

**********************
Impact library
**********************

Impact library callable through the Impact C API.



**********************
Simulink block
**********************

MPC-ready Impact Simulink block

